@@ -68,12 +68,12 @@ class Stack:
             stck.push(self.pop())
         return stck
     @classmethod
-    def merge(self, s1, s2):
+    def merge(self, s1: Stack, s2: Stack):
         try:
             stck = Stack()
             tmp1 = s1.__top
             tmp2 = s2.__top
-            while tmp1 is no None:
+            while tmp1 is not None:
                 stck.push(tmp1.data)
                 tmp1 = tmp1.next
             while tmp2 is not None:
@@ -82,4 +82,18 @@ class Stack:
             del tmp1, tmp2
             return stck
         except Exception as ex:
-            print("Error, %s" %ex)
\ No newline at end of file
+            print("Error, %s" %ex)
+    @classmethod
+    def swap(self, s1: Stack, s2: Stack):
+        bid1 = Stack()
+        bid2 = Stack()
+        while not t1.empty():
+            bid1.push(t1.pop())
+        while not t2.empty():
+            bid2.push(t2.pop())
+        while not bid1.empty():
+            t2.push(bid1.pop())
+        while not bid2.empty():
+            t1.push(bid2.pop())
+        del bid1, bid2
+    
\ No newline at end of file
